==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/solutions/kotlin/inputs/ApplicationDefinitionArtifactArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.solutions.kotlin.inputs

import com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs.builder
import com.pulumi.azurenative.solutions.kotlin.enums.ApplicationArtifactType
import com.pulumi.azurenative.solutions.kotlin.enums.ApplicationDefinitionArtifactName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Application definition artifact.
 * @property name The managed application definition artifact name.
 * @property type The managed application definition artifact type.
 * @property uri The managed application definition artifact blob uri.
 */
public data class ApplicationDefinitionArtifactArgs(
    public val name: Output<Either<String, ApplicationDefinitionArtifactName>>,
    public val type: Output<ApplicationArtifactType>,
    public val uri: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs> {
    override fun toJava(): com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs =
        com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs.builder()
            .name(
                name.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uri(uri.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationDefinitionArtifactArgs].
 */
@PulumiTagMarker
public class ApplicationDefinitionArtifactArgsBuilder internal constructor() {
    private var name: Output<Either<String, ApplicationDefinitionArtifactName>>? = null

    private var type: Output<ApplicationArtifactType>? = null

    private var uri: Output<String>? = null

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("rqygtnjnwbyofqnm")
    public suspend fun name(`value`: Output<Either<String, ApplicationDefinitionArtifactName>>) {
        this.name = value
    }

    /**
     * @param value The managed application definition artifact type.
     */
    @JvmName("wtngdemldllvxahc")
    public suspend fun type(`value`: Output<ApplicationArtifactType>) {
        this.type = value
    }

    /**
     * @param value The managed application definition artifact blob uri.
     */
    @JvmName("syirliiligfxfpsu")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("ciclqcjoahvtjglc")
    public suspend fun name(`value`: Either<String, ApplicationDefinitionArtifactName>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("ilcuamaflltsuelr")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationDefinitionArtifactName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("vardlkwopnixitae")
    public fun name(`value`: ApplicationDefinitionArtifactName) {
        val toBeMapped = Either.ofRight<String, ApplicationDefinitionArtifactName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The managed application definition artifact type.
     */
    @JvmName("ivwwxfdtpscukkfv")
    public suspend fun type(`value`: ApplicationArtifactType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The managed application definition artifact blob uri.
     */
    @JvmName("qrbbdgfqexlmqxeg")
    public suspend fun uri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): ApplicationDefinitionArtifactArgs = ApplicationDefinitionArtifactArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        type = type ?: throw PulumiNullFieldException("type"),
        uri = uri ?: throw PulumiNullFieldException("uri"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/solutions/kotlin/inputs/ApplicationDefinitionArtifactArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.solutions.kotlin.inputs

import com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs.builder
import com.pulumi.azurenative.solutions.kotlin.enums.ApplicationArtifactType
import com.pulumi.azurenative.solutions.kotlin.enums.ApplicationDefinitionArtifactName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Application definition artifact.
 * @property name The managed application definition artifact name.
 * @property type The managed application definition artifact type.
 * @property uri The managed application definition artifact blob uri.
 */
public data class ApplicationDefinitionArtifactArgs(
    public val name: Output<Either<String, ApplicationDefinitionArtifactName>>,
    public val type: Output<ApplicationArtifactType>,
    public val uri: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs> {
    override fun toJava(): com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs =
        com.pulumi.azurenative.solutions.inputs.ApplicationDefinitionArtifactArgs.builder()
            .name(
                name.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uri(uri.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationDefinitionArtifactArgs].
 */
@PulumiTagMarker
public class ApplicationDefinitionArtifactArgsBuilder internal constructor() {
    private var name: Output<Either<String, ApplicationDefinitionArtifactName>>? = null

    private var type: Output<ApplicationArtifactType>? = null

    private var uri: Output<String>? = null

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("gogprdqibjwfuoed")
    public suspend fun name(`value`: Output<Either<String, ApplicationDefinitionArtifactName>>) {
        this.name = value
    }

    /**
     * @param value The managed application definition artifact type.
     */
    @JvmName("ndondujawujxwlyf")
    public suspend fun type(`value`: Output<ApplicationArtifactType>) {
        this.type = value
    }

    /**
     * @param value The managed application definition artifact blob uri.
     */
    @JvmName("itkufdvqglityuuw")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("hhpvldjbunihhkqf")
    public suspend fun name(`value`: Either<String, ApplicationDefinitionArtifactName>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("hrdphswesjjqpsko")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationDefinitionArtifactName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The managed application definition artifact name.
     */
    @JvmName("rfrnqivneqggfvas")
    public fun name(`value`: ApplicationDefinitionArtifactName) {
        val toBeMapped = Either.ofRight<String, ApplicationDefinitionArtifactName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The managed application definition artifact type.
     */
    @JvmName("cbxuwiypritagsis")
    public suspend fun type(`value`: ApplicationArtifactType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The managed application definition artifact blob uri.
     */
    @JvmName("chpropsffkffpbia")
    public suspend fun uri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): ApplicationDefinitionArtifactArgs = ApplicationDefinitionArtifactArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        type = type ?: throw PulumiNullFieldException("type"),
        uri = uri ?: throw PulumiNullFieldException("uri"),
    )
}
